---
title: "Scalable survival analysis in a French hospital?"
author: "Jean Feydy"
institute: ""
topic: ""
theme: "metropolis"
colortheme:
fonttheme:
fontsize: 11pt
linkcolor: black
urlcolor: blue
linkstyle: bold
aspectratio: 169
titlegraphic: 
logo:
date:
section-titles: false
toc: false
---


## Today's presentation

 \
**1.** **Technological** context: the $\BR{GPU}$ revolution.

 \
**2. Human** context: a triple intersection $\BR{CS + Stats + Medicine}$.

 \
**3. Experience** feedback: three years of work in $\BR{pharmaco-vigilance}$.


# Technological context


## Towards a continuous description of large datasets `~\cite{peyre2011numerical,umapprime}`{=latex}

`\vspace*{1cm}`{=latex}

::: columns
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/6n-graf.pdf){height=3cm}

 \
Simple **graph**.

`\end{center}`{=latex}
::::
:::: {.column width=30%}
`\begin{center}`{=latex}
![](images/knn_graph.png){height=3cm}

 \
Underlying **surface**.

`\end{center}`{=latex}
::::
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/primes_umap_8e6.png){height=3cm}

 \
**Visualization** with UMAP.

`\end{center}`{=latex}
::::
:::

`\begin{center}`{=latex}

 \
The $\BR{language of continuous mathematics}$ has become mainstream in **data analysis** : \
gradient, density, manifold, test function...

`\end{center}`{=latex}


## A rich history in physics `~\cite{solar_system,ideal_gas,nabizadeh2022covector}`{=latex}

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=35%}
`\begin{center}`{=latex}
![](images/solar_system.png){height=3.5cm}

 \
The **solar system**.

`\end{center}`{=latex}
::::
:::: {.column width=40%}
`\begin{center}`{=latex}
![](images/ideal_gas.png){height=3.5cm}

 \
The **ideal gas** model.

`\end{center}`{=latex}
::::
:::: {.column width=25%}
`\begin{center}`{=latex}
![](images/fluid_simulation.png){height=3.5cm}

 \
**Fluid** simulation.

`\end{center}`{=latex}
::::
:::

`\begin{center}`{=latex}

 \
Research in **physics** $~~\Longleftrightarrow~~$ **High Performance super-Computers** \
Access restricted to $\BR{institutional centres}$.

`\end{center}`{=latex}



## A recent history in computer graphics

`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=33%}
`\begin{center}`{=latex}
![](images/FF.png){height=3.5cm}

 \
FFVII on the PS1 -- 1997.

`\end{center}`{=latex}
::::
:::: {.column width=33%}
`\begin{center}`{=latex}
![](images/FF_remaster.jpg){height=3.5cm}

 \
FFVII on the PS4 -- 2020.

`\end{center}`{=latex}
::::
:::: {.column width=33%}
`\begin{center}`{=latex}
![](images/jensen_huang.jpg){height=3.5cm}

 \
Jensen Huang -- 2022.

`\end{center}`{=latex}
::::
:::

`\begin{center}`{=latex}

 \
Research in **computer graphics** $~~\Longleftrightarrow~~$ **Graphics Processing Units** \
$\BR{Accessible}$ to most research labs: revolutionary impact.

`\end{center}`{=latex}


## Modern hardware is the workhorse of the "AI revolution"

Statistics and machine learning have been studied for **decades**. \
**Breakthrough** in 2010-15 : using $\BR{PlayStations}$ to do $\BR{science}$ became **easy**.

::: columns
:::: {.column width=70%}

 \
 \
Research effort at all levels towards:

- Increasingly powerful **computers**.
- Increasingly convenient **software toolkits**.
- Increasingly relevant **models**.

 \
 \
**Spectacular results** in a few applications \
$\Longrightarrow~~$ massive $\BR{investments}$, industry + governments.

::::
:::: {.column width=30%}
`\begin{center}`{=latex}

![](images/ampere.jpg){height=4cm}

 \
**10,000 cores** on a GPU.

`\end{center}`{=latex}
::::
:::


## Example : the KeOps library `\texttt{~~www.kernel-operations.io}`{=latex}

`\begin{center}`{=latex}

![](images/keops.pdf){height=7cm}

`\end{center}`{=latex}


# Human context

## HeKA: a translational research team

`\begin{center}`{=latex}

![](images/HeKA.pdf){height=7cm}

`\end{center}`{=latex}


## PariSanté Campus: a fancy workplace for research on digital health


`\vspace*{.5cm}`{=latex}

::: columns
:::: {.column width=40%}
`\begin{center}`{=latex}
![](images/Inria_PSC.png){height=4.5cm}

`\end{center}`{=latex}
::::
:::: {.column width=60%}
`\begin{center}`{=latex}
![](images/PariSanteCampus.jpg){height=4.5cm}

`\end{center}`{=latex}
::::
:::


## Mission: highlight public data warehouses

Our main sources:

- Patient records from the Pompidou and Necker Hospitals.
- National Rare Diseases Data Bank.
- Data from French $\BR{cartes vitales}$ -- décret R 1461-12 du 29 juin 2021.

`\begin{center}`{=latex}

 \
Strong support from Inria, Inserm, UPCité for \
**methodological** research $\BR{and}$ **"simple" applications** to new data. \
 \
$\Longrightarrow~~$ A proven $\BR{``translational''}$ research model that is\
well-established in the UK and growing at Inria.

`\end{center}`{=latex}


## Status differences

At **Inria** -- plenty of **freedom**:

- Tenure around age 30.
- Full-time research, with remote work.
- Support for projects planned over 5 years.
- Dedicated **support** teams: skilled and supportive.

 \
At the **hospital** -- significant **pressure** :

- Tenure around age 40.
- $\BR{Care + Teaching + Research}$, **day and night.**
- Fully embracing the *publish or perish* ethos with **SIGAPS** points.
- A $\BR{stable internet connection}$ is **not even** guaranteed!


## Cultural differences

What is a $\BR{scientific truth}$?

- In math: a formal **proof**.  
- In computer science: well-**tested** software.  
- In medicine: an $\BR{expert consensus}$... and great responsibilities.  

`\begin{center}`{=latex}  

 \
In medicine and biology, the **"prestige of the white gown"** is immense.  

**Analysts** are often seen as **"pen pushers"** or **subordinates**.  

Shifting $\BR{mindsets}$ is a challenge for our field.  

`\end{center}`{=latex}  


## Considering these factors is essential to succeed

**Long-term strategy**, enabled by Inria:

1. **Understand** the existing consensus,  
   through lengthy discussions with doctors.  
   \  

2. **Gradually introduce** modern tools (GPUs...),  
   ensuring perfect $\BR{backward compatibility}$ with standard methods.  
   \  

3. Leverage **experience** and **credibility** gained  
   to introduce **new methods**, when $\BR{necessary}$.  


# Experience in pharmaco-vigilance

## Survival analysis: a classification problem on time series

`\begin{center}`{=latex}

![](images/survival.png){height=4.5cm}

`\end{center}`{=latex}

**Fundamental problem** for:

- **Factories**: Which part will break next?  
- **Businesses**: Which customer will stop returning first?  
- **Doctors**: Which patient will develop cancer next?  


## Survival analysis: in practice

**Standard Model**: Cox Proportional Hazards (1972).  
$\qquad$ Time-dependent descriptors: Weighted Cumulated Exposures (WCE), ...  

 \
**Implementation**: $~\texttt{survival}~$ and $~\texttt{WCE}~$ packages for R -- 10M+ downloads.  

Excellent packaging, but lacks GPU support:  

- Acceptable for clinical trials (1k--10k patients).  
- Prohibitively **slow** for large-scale studies,  
  especially with time-dependent variables.  

 \
$\textbf{Epi-Phare with \BR{Anne-Sophie Jannot} -- 150k€}$ to scale up to nation-wide cohorts.  
$\qquad$ **20 years** of "receipts" from $\BR{cartes vitales}$, for **70M+ French citizens**.  


## 2021 -- Implementation on GPUs

$\BR{Striking similarity}$ between survival and learning models:  

- **Cox model** = **logistic regression** on a **graph** (1 node = 1 patient).  
- Weighted Cumulative Exposures = **kernel** features.  

I developed a **fast GPU solver** for these methods,  
which Alexis Van Straaten packaged into an **R library**.  

$\BR{survivalGPU}$ (for R and Python) produces $\BR{exactly}$ the same output  
as the standard **survival** and **WCE** packages, but is $\BR{1,000 times faster}$.  

Two main outcomes:  

- **Scalability**: work with **millions of patients** in just a few minutes.  
- **Bootstrap and permutations**: repeat the same experiment 1,000 times  
  $\qquad$ to estimate confidence intervals.  


## 2022 -- Gaining access to carte vitale data (SNDS)

- **Inria** received authorization from the authorities via decree in June 2021.  
- Inria funded **my one-week training** in May 2022 -- thanks!  

 \
$\BR{Problem:}$ The $\texttt{Ameli.fr}$ cloud is **not designed for innovative methods**.  

Obsolete hardware configuration, with only three software options (c. 2005):  

- Microsoft **Excel**.  
- SAS (a **SQL** query system).  
- **R** with a **frozen** collection of standard packages.  

 \
$\textbf{We need access to a \BR{modern} machine (GPU + Python + R),}$  
aligned with the **security** guidelines documented by the health insurance system.  


## 2023 -- Gaining access to a secure computer...

We got stuck on this point for **more than a year**:  

- $\BR{Plan A:}$ Our request to use the Pompidou Hospital cloud was rejected.  

- $\BR{Plan B:}$ We purchased a **modern workstation** (€5,000)...  
  only to realize that it could not be approved for use.  

- $\BR{Plan C:}$ Inria's IT department is working on a secure cloud solution...  
  but cannot prioritize **specific procedures** for this data.  

The situation around secure clouds is very $\BR{confusing}$:  

- **Old procedures** have been deprecated.  
- **New platforms** like the Health Data Hub only support a few **pilot projects**.  

$\Longrightarrow$ Fortunately, we met **Emmanuel Bacry** at PariSanté Campus!


## 2024 -- Our first steps with the data

Funding for the project now comes from the Pr[ai]rie institute. \
Emmanuel hired **Antoine Poirot-Bourdain** for a 2 years contract + 3 years of PhD thesis.

**Getting access** to drug reimbursement records over 5 years for 3,000,000 citizens:

- Hard to get past the usual regulatory boards without \
  a specific, **narrow clinical question**. \
   \
- Fairly easy to $\BR{motivate the development of original methods}$ via the **Inria** access, \
  thanks to Anne Combe and Michel Dojat. \
   \
- Then, the **Health Data Hub** could help us to get the data **on their secure platform**, \
  thanks to Lise Vasteenkiste.


## 2025 -- Finally some real medicine?

The HDH platform has **rough edges**... but $\BR{it works}$!

Our first questions:

- What does real-life carte vitale data **look like**? \
- How do we estimate **drug exposure** from reimbursement data? \
- What are the adverse effects that are **easy to infer** from our data?\
- Which drugs can we use as positive and negative **test cases**? \
- Basic methods for adverse effect detection raise too many **false positives**. \
  Do **modern methods** perform better?

We now work with a $\BR{healthy mix}$ **of mathematicians and pharmacists**. \
I am also **tidying up survivalGPU** and adding support for Lasso, ElasticNet, etc.


## We are getting there...


`\vspace*{.5cm}`{=latex}

`\begin{center}`{=latex}

![](images/pipeline.png){height=4cm}

`\end{center}`{=latex}


The $\BR{work accomplished}$ over the last decade is **substantial**.  
However, the issue of digital **infrastructure** remains a $\BR{major blind spot}$.  

Information flow is poor:  

- A proliferation of **incomprehensible** and **deprecated** procedures.  
- **Leadership** is generally unaware of $\BR{on-the-ground bottlenecks}$.  
- We got lucky.

## Conclusion

**Hospitals** are contrasting environments:  

- **Futuristic** equipment in interventional radiology.  
- "Our unit **cannot access its emails** today."  
- $\BR{Amazing doctors}$ working under absurd conditions.  

 \
As an **Inria researcher**:  

- I have learnt a great deal through **collaborating with doctors and pharmacists**.  
- I want to prioritize projects $\BR{that benefit all French citizens}$.  

`\begin{center}`{=latex}

 \
I am $\textbf{\BR{tired}, but cautiously \BR{optimistic}}$: we're finally ready to do some science. \
Hopefully, the **new generation** will be able to build on this groundwork.

`\end{center}`{=latex}



# References